Tutorial : creating new objects
===============================

.. include:: new_objects/create_book.rst

.. include:: new_objects/create_account.rst

.. include:: new_objects/create_commodity.rst

.. include:: new_objects/create_transaction.rst

.. include:: new_objects/create_business.rst